# Generated by Django 5.0.6 on 2024-08-02 11:28

# This migration converts the `credential_id_sha256` field from binary to hex.
# This is necessary to support MySQL in particular, which cannot index binary without special instructions.
# See https://github.com/Stormbase/django-otp-webauthn/issues/17 for more information.

from django.db import migrations, models


def forwards(apps, schema_editor):
    WebAuthnCredential = apps.get_model("django_otp_webauthn", "WebAuthnCredential")
    for credential in WebAuthnCredential.objects.all():
        credential.credential_id_sha256_txt = credential.credential_id_sha256.hex()
        credential.save()


def backwards(apps, schema_editor):
    WebAuthnCredential = apps.get_model("django_otp_webauthn", "WebAuthnCredential")
    for credential in WebAuthnCredential.objects.all():
        credential.credential_id_sha256 = bytes.fromhex(
            credential.credential_id_sha256_txt
        )
        credential.save()


class Migration(migrations.Migration):
    dependencies = [
        ("django_otp_webauthn", "0002_timestamps"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="webauthncredential", name="webauthncredential_sha256_idx"
        ),
        migrations.AddField(
            model_name="webauthncredential",
            name="credential_id_sha256_txt",
            field=models.CharField(
                default="",
                editable=False,
                max_length=64,
                verbose_name="hashed credential id",
            ),
            preserve_default=False,
        ),
        migrations.RunPython(forwards, backwards, elidable=True),
        migrations.RemoveField(
            model_name="webauthncredential", name="credential_id_sha256"
        ),
        migrations.RenameField(
            model_name="webauthncredential",
            old_name="credential_id_sha256_txt",
            new_name="credential_id_sha256",
        ),
        migrations.AlterField(
            model_name="webauthncredential",
            name="credential_id_sha256",
            field=models.CharField(
                editable=False,
                max_length=64,
                unique=True,
                verbose_name="hashed credential id",
            ),
        ),
        migrations.AddIndex(
            model_name="webauthncredential",
            index=models.Index(
                fields=["credential_id_sha256"], name="webauthncredential_sha256_idx"
            ),
        ),
    ]
